exists_in_path

Function exists_in_path 

pub fn exists_in_path(_home: &Home) -> bool
Checks if the Rokit binaries directory is in the system PATH.

Returns true if the directory is in the PATH, false otherwise.